I understand this was supposed to be mentioned here: Herald ignores commits that are ancestors of permanent refs if they were previously pushed to some other non-permanent ref.
- Queries
- All Stories
- Search
- Advanced Search
- Transactions
- Transaction Logs
All Stories
Sep 11 2019
Sep 10 2019
Sep 9 2019
0.00000000001 is very funny and we would be losing a truly great joke at such a young age
Left Nav
There may also be no Application in contexts where we want to render a global search menu, notably the 404 page:
Sep 8 2019
Vaguely adjacent:
Sep 7 2019
Now that we are on RDS I can confirm that MySQL also has ONLY_FULL_GROUP_BY enabled by default.
Sep 6 2019
I think I missed one case here: the global preference will currently show custom personal queries for the viewing user, but selecting these queries won't work (at least, not completely) for other users. Instead, the control should offer only hard-coded options and global queries.
Sep 5 2019
But did you check your spam folder? 😄
But did you check your spam folder? 😄
I attempted to register for a developer account and am receiving neither an email verification email nor a password reset email. 🤷
Our behavior appears to be correct when the load balancer is an AWS ELB.
Sep 4 2019
That actually using MySQL official Docker image.
Sep 3 2019
There are only 23 occurrences of the string "GROUP BY" in the codebase, and, from inspection, many obviously do not conflict with ONLY_FULL_GROUP_BY.
Also remaining is to extend this behavior to the HTTP pathway (and to Mercurial/SVN, eventually).
- if we have already retried 3 times, do not retry;
we'll reduce silly client-visible behavior where you request /tourtle.git instead of /turtle.git and the server seems confused...
Sep 2 2019
The migration in PHI1403 seems to have gone through cleanly. This workflow can continue to improve, but it's in relatively good shape now.
A generally cleaner version of this would also fix the parallelization TODO (just above the patch in the previous comment). This probably needs FutureIterator to be better at managing in-flight changes to the working set.
Everything here appears to have made it to production cleanly.
Sep 1 2019
Anecdata: locally, using 2 subprocesses went twice as fast (~85s -> ~42s). 4 subprocesses chopped another ~20% of the time off (~42s > ~35s). It stopped getting faster at 4. However, the largest table took 24s, so even if this was completely parallelizable we wouldn't expect it to drop lower than that.
Anecdotally from the last time around, gzipping the tarball didn't really do much. Possibly, this might more broadly imply that we'd be better off not compressing repository backups.
I believe I've moved "core/" from "instances.queryinstances" and sequenced all the followup changes properly, now, and that the only remaining piece is glue.